@@ -2,6 +2,8 @@
 
 from typing import Dict, Union, cast
 
+from deprecated.sphinx import deprecated
+
 from xrpl.asyncio.clients import Client, XRPLRequestFailureException
 from xrpl.constants import XRPLException
 from xrpl.core.addresscodec import is_valid_xaddress, xaddress_to_classic_address
@@ -30,7 +32,7 @@ async def does_account_exist(
         XRPLRequestFailureException: if the transaction fails.
     """
     try:
-        await get_account_info(address, client)
+        await get_account_root(address, client, ledger_index=ledger_index)
         return True
     except XRPLRequestFailureException as e:
         if e.error == "actNotFound":
@@ -78,7 +80,9 @@ async def get_balance(
     Returns:
         The balance of the address.
     """
-    return int((await get_account_root(address, client))["Balance"])
+    return int(
+        (await get_account_root(address, client, ledger_index=ledger_index))["Balance"]
+    )
 
 
 async def get_account_root(
@@ -97,14 +101,35 @@ async def get_account_root(
 
     Returns:
         The AccountRoot dictionary for the address.
+
+    Raises:
+        XRPLRequestFailureException: if the rippled API call fails.
     """
-    account_info = await get_account_info(address, client, ledger_index)
+    classic_address = address
+
+    if is_valid_xaddress(address):
+        classic_address, _, _ = xaddress_to_classic_address(address)
+
+    account_info = await client._request_impl(
+        AccountInfo(
+            account=classic_address,
+            ledger_index=ledger_index,
+        )
+    )
+
+    if not account_info.is_successful():
+        raise XRPLRequestFailureException(account_info.result)
+
     return cast(Dict[str, Union[int, str]], account_info.result["account_data"])
 
 
+@deprecated(
+    reason="Sending an AccountInfo request directly is just as easy to use.",
+    version="1.8.0",
+)
 async def get_account_info(
     address: str, client: Client, ledger_index: Union[str, int] = "validated"
-) -> Response:
+) -> Response:  # pragma: no cover
     """
     Query the ledger for account info of given address.
 
@@ -125,6 +150,7 @@ async def get_account_info(
     """
     if is_valid_xaddress(address):
         address, _, _ = xaddress_to_classic_address(address)
+
     if isinstance(ledger_index, str) and ledger_index not in {
         "validated",
         "current",
@@ -134,7 +160,7 @@ async def get_account_info(
             "`ledger_index` is not valid - must be an `int` or one of {'validated', "
             "'current', 'closed'}."
         )
-    response = await client.request_impl(
+    response = await client._request_impl(
         AccountInfo(
             account=address,
             ledger_index=ledger_index,
