@@ -1,22 +1,34 @@
 """Async methods for working with transactions on the XRP Ledger."""
 from xrpl.asyncio.transaction.ledger import get_transaction_from_hash
 from xrpl.asyncio.transaction.main import (
+    autofill,
+    autofill_and_sign,
     safe_sign_and_autofill_transaction,
     safe_sign_and_submit_transaction,
     safe_sign_transaction,
+    sign,
+    sign_and_submit,
+    submit,
     submit_transaction,
     transaction_json_to_binary_codec_form,
 )
 from xrpl.asyncio.transaction.reliable_submission import (
     XRPLReliableSubmissionException,
     send_reliable_submission,
+    submit_and_wait,
 )
 
 __all__ = [
+    "autofill",
+    "autofill_and_sign",
     "get_transaction_from_hash",
     "safe_sign_transaction",
     "safe_sign_and_autofill_transaction",
     "safe_sign_and_submit_transaction",
+    "sign",
+    "sign_and_submit",
+    "submit",
+    "submit_and_wait",
     "submit_transaction",
     "transaction_json_to_binary_codec_form",
     "send_reliable_submission",
