@@ -2,18 +2,24 @@
 
 from typing import Optional
 
+from deprecated.sphinx import deprecated
+
 from xrpl.asyncio.clients import Client, XRPLRequestFailureException
 from xrpl.models.requests import Tx
 from xrpl.models.response import Response
 
 
+@deprecated(
+    reason="Sending a Tx request directly is just as easy to use.",
+    version="1.8.0",
+)
 async def get_transaction_from_hash(
     tx_hash: str,
     client: Client,
     binary: bool = False,
     min_ledger: Optional[int] = None,
     max_ledger: Optional[int] = None,
-) -> Response:
+) -> Response:  # pragma: no cover
     """
     Given a transaction hash, fetch the corresponding transaction from the ledger.
 
@@ -38,7 +44,7 @@ async def get_transaction_from_hash(
     Raises:
         XRPLRequestFailureException: if the transaction fails.
     """
-    response = await client.request_impl(
+    response = await client._request_impl(
         Tx(
             transaction=tx_hash,
             binary=binary,
