@@ -9,12 +9,12 @@ from xrpl.asyncio.clients import Client, XRPLRequestFailureException
 from xrpl.asyncio.ledger import get_fee, get_latest_validated_ledger_sequence
 from xrpl.constants import XRPLException
 from xrpl.core.addresscodec import is_valid_xaddress, xaddress_to_classic_address
-from xrpl.core.binarycodec import encode, encode_for_signing
-from xrpl.core.keypairs.main import sign
-from xrpl.models.requests import ServerState, SubmitOnly
+from xrpl.core.binarycodec import encode, encode_for_multisigning, encode_for_signing
+from xrpl.core.keypairs.main import sign as keypairs_sign
+from xrpl.models.requests import ServerInfo, ServerState, SubmitOnly
 from xrpl.models.response import Response
 from xrpl.models.transactions import EscrowFinish
-from xrpl.models.transactions.transaction import Transaction
+from xrpl.models.transactions.transaction import Signer, Transaction
 from xrpl.models.transactions.transaction import (
     transaction_json_to_binary_codec_form as model_transaction_to_binary_codec,
 )
@@ -23,12 +23,19 @@ from xrpl.utils import drops_to_xrp, xrp_to_drops
 from xrpl.wallet.main import Wallet
 
 _LEDGER_OFFSET: Final[int] = 20
-
+# Sidechains are expected to have network IDs above this.
+# Networks with ID above this restricted number are expected to specify an
+# accurate NetworkID field in every transaction to that chain to prevent replay attacks.
+# Mainnet and testnet are exceptions.
+# More context: https://github.com/XRPLF/rippled/pull/4370
+_RESTRICTED_NETWORKS = 1024
+_REQUIRED_NETWORKID_VERSION = "1.11.0"
+_HOOKS_TESTNET_ID = 21338
 # TODO: make this dynamic based on the current ledger fee
 _ACCOUNT_DELETE_FEE: Final[int] = int(xrp_to_drops(2))
 
 
-async def safe_sign_and_submit_transaction(
+async def sign_and_submit(
     transaction: Transaction,
     wallet: Wallet,
     client: Client,
@@ -51,18 +58,20 @@ async def safe_sign_and_submit_transaction(
         The response from the ledger.
     """
     if autofill:
-        transaction = await safe_sign_and_autofill_transaction(
-            transaction, wallet, client, check_fee
-        )
+        transaction = await autofill_and_sign(transaction, wallet, client, check_fee)
     else:
-        transaction = await safe_sign_transaction(transaction, wallet, check_fee)
-    return await submit_transaction(transaction, client)
+        transaction = await sign(transaction, wallet, check_fee)
+    return await submit(transaction, client)
 
 
-async def safe_sign_transaction(
+safe_sign_and_submit_transaction = sign_and_submit
+
+
+async def sign(
     transaction: Transaction,
     wallet: Wallet,
     check_fee: bool = True,
+    multisign: bool = False,
 ) -> Transaction:
     """
     Signs a transaction locally, without trusting external rippled nodes.
@@ -72,29 +81,53 @@ async def safe_sign_transaction(
         wallet: the wallet with which to sign the transaction.
         check_fee: whether to check if the fee is higher than the expected transaction
             type fee. Defaults to True.
+        multisign: whether to sign the transaction for a multisignature transaction.
 
     Returns:
         The signed transaction blob.
     """
+    if multisign:
+        signature = keypairs_sign(
+            bytes.fromhex(
+                encode_for_multisigning(
+                    transaction.to_xrpl(),
+                    wallet.classic_address,
+                )
+            ),
+            wallet.private_key,
+        )
+        tx_dict = transaction.to_dict()
+        tx_dict["signers"] = [
+            Signer(
+                account=wallet.classic_address,
+                txn_signature=signature,
+                signing_pub_key=wallet.public_key,
+            )
+        ]
+        return Transaction.from_dict(tx_dict)
+
     if check_fee:
         await _check_fee(transaction)
     transaction_json = _prepare_transaction(transaction, wallet)
     serialized_for_signing = encode_for_signing(transaction_json)
     serialized_bytes = bytes.fromhex(serialized_for_signing)
-    signature = sign(serialized_bytes, wallet.private_key)
+    signature = keypairs_sign(serialized_bytes, wallet.private_key)
     transaction_json["TxnSignature"] = signature
-    return cast(Transaction, Transaction.from_xrpl(transaction_json))
+    return Transaction.from_xrpl(transaction_json)
 
 
-async def safe_sign_and_autofill_transaction(
+safe_sign_transaction = sign
+
+
+async def autofill_and_sign(
     transaction: Transaction,
     wallet: Wallet,
     client: Client,
     check_fee: bool = True,
 ) -> Transaction:
     """
-    Signs a transaction locally, without trusting external rippled nodes. Autofills
-    relevant fields.
+    Autofills relevant fields. Then, signs a transaction locally, without trusting
+    external rippled nodes.
 
     Args:
         transaction: the transaction to be signed.
@@ -112,14 +145,17 @@ async def safe_sign_and_autofill_transaction(
     if check_fee:
         await _check_fee(transaction, client)
 
-    return await safe_sign_transaction(
-        await autofill(transaction, client), wallet, False
-    )
+    return await sign(await autofill(transaction, client), wallet, False)
 
 
-async def submit_transaction(
+safe_sign_and_autofill_transaction = autofill_and_sign
+
+
+async def submit(
     transaction: Transaction,
     client: Client,
+    *,
+    fail_hard: bool = False,
 ) -> Response:
     """
     Submits a transaction to the ledger.
@@ -127,6 +163,9 @@ async def submit_transaction(
     Args:
         transaction: the Transaction to be submitted.
         client: the network client with which to submit the transaction.
+        fail_hard: an optional boolean. If True, and the transaction fails for
+            the initial server, do not retry or relay the transaction to other
+            servers. Defaults to False.
 
     Returns:
         The response from the ledger.
@@ -135,13 +174,18 @@ async def submit_transaction(
         XRPLRequestFailureException: if the rippled API call fails.
     """
     transaction_blob = encode(transaction.to_xrpl())
-    response = await client.request_impl(SubmitOnly(tx_blob=transaction_blob))
+    response = await client._request_impl(
+        SubmitOnly(tx_blob=transaction_blob, fail_hard=fail_hard)
+    )
     if response.is_successful():
         return response
 
     raise XRPLRequestFailureException(response.result)
 
 
+submit_transaction = submit
+
+
 def _prepare_transaction(
     transaction: Transaction,
     wallet: Wallet,
@@ -180,7 +224,9 @@ def _prepare_transaction(
     return transaction_json
 
 
-async def autofill(transaction: Transaction, client: Client) -> Transaction:
+async def autofill(
+    transaction: Transaction, client: Client, signers_count: Optional[int] = None
+) -> Transaction:
     """
     Autofills fields in a transaction. This will set `sequence`, `fee`, and
     `last_ledger_sequence` according to the current state of the server this Client is
@@ -189,17 +235,23 @@ async def autofill(transaction: Transaction, client: Client) -> Transaction:
     Args:
         transaction: the transaction to be signed.
         client: a network client.
+        signers_count: the expected number of signers for this transaction.
+            Only used for multisigned transactions.
 
     Returns:
         The autofilled transaction.
     """
     transaction_json = transaction.to_dict()
+    if not client.network_id:
+        await _get_network_id_and_build_version(client)
+    if "network_id" not in transaction_json and _tx_needs_networkID(client):
+        transaction_json["network_id"] = client.network_id
     if "sequence" not in transaction_json:
         sequence = await get_next_valid_seq_number(transaction_json["account"], client)
         transaction_json["sequence"] = sequence
     if "fee" not in transaction_json:
         transaction_json["fee"] = await _calculate_fee_per_transaction_type(
-            transaction, client
+            transaction, client, signers_count
         )
     if "last_ledger_sequence" not in transaction_json:
         ledger_sequence = await get_latest_validated_ledger_sequence(client)
@@ -207,6 +259,105 @@ async def autofill(transaction: Transaction, client: Client) -> Transaction:
     return Transaction.from_dict(transaction_json)
 
 
+async def _get_network_id_and_build_version(client: Client) -> None:
+    """
+    Get the network id and build version of the connected server.
+
+    Args:
+        client: The network client to use to send the request.
+
+    Raises:
+        XRPLRequestFailureException: if the rippled API call fails.
+    """
+    response = await client._request_impl(ServerInfo())
+    if response.is_successful():
+        if "network_id" in response.result["info"]:
+            client.network_id = response.result["info"]["network_id"]
+        if not client.build_version and "build_version" in response.result["info"]:
+            client.build_version = response.result["info"]["build_version"]
+        return
+
+    raise XRPLRequestFailureException(response.result)
+
+
+def _tx_needs_networkID(client: Client) -> bool:
+    """
+    Determines whether the transactions required network ID to be valid.
+    Transaction needs networkID if later than restricted ID and either
+        the network is hooks testnet or build version is >= 1.11.0.
+    More context: https://github.com/XRPLF/rippled/pull/4370
+
+    Args:
+        client (Client): The network client to use to send the request.
+
+    Returns:
+        bool: whether the transactions required network ID to be valid
+    """
+    if client.network_id and client.network_id > _RESTRICTED_NETWORKS:
+        # TODO: remove the buildVersion logic when 1.11.0 is out and widely used.
+        # Issue: https://github.com/XRPLF/xrpl-py/issues/595
+        if (
+            client.build_version
+            and _is_not_later_rippled_version(
+                _REQUIRED_NETWORKID_VERSION, client.build_version
+            )
+        ) or client.network_id == _HOOKS_TESTNET_ID:
+            return True
+    return False
+
+
+def _is_not_later_rippled_version(source: str, target: str) -> bool:
+    """
+    Determines whether the source version is not a later release than the
+        target version.
+
+    Args:
+        source: the source rippled version.
+        target: the target rippled version.
+
+    Returns:
+        bool: true if source is earlier, false otherwise.
+    """
+    if source == target:
+        return True
+    source_decomp = source.split(".")
+    target_decomp = target.split(".")
+    source_major, source_minor = int(source_decomp[0]), int(source_decomp[1])
+    target_major, target_minor = int(target_decomp[0]), int(target_decomp[1])
+
+    # Compare major version
+    if source_major != target_major:
+        return source_major < target_major
+
+    # Compare minor version
+    if source_minor != target_minor:
+        return source_minor < target_minor
+
+    source_patch = source_decomp[2].split("-")
+    target_patch = target_decomp[2].split("-")
+    source_patch_version = int(source_patch[0])
+    target_patch_version = int(target_patch[0])
+
+    # Compare patch version
+    if source_patch_version != target_patch_version:
+        return source_patch_version < target_patch_version
+
+    # Compare release version
+    if len(source_patch) != len(target_patch):
+        return len(source_patch) > len(target_patch)
+
+    if len(source_patch) == 2:
+        # Compare release types
+        if not source_patch[1][0].startswith(target_patch[1][0]):
+            return source_patch[1] < target_patch[1]
+        # Compare beta versions
+        if source_patch[1].startswith("b"):
+            return int(source_patch[1][1:]) < int(target_patch[1][1:])
+        # Compare rc versions
+        return int(source_patch[1][2:]) < int(target_patch[1][2:])
+    return False
+
+
 def _validate_account_xaddress(
     json: Dict[str, Any], account_field: str, tag_field: str
 ) -> None:
@@ -269,23 +420,23 @@ async def _check_fee(transaction: Transaction, client: Optional[Client] = None)
     Raises:
         XRPLException: if the transaction fee is higher than the expected fee.
     """
-    # Calculate the expected fee from the network load and transaction type
-    expected_fee = await _calculate_fee_per_transaction_type(transaction, client)
+    expected_fee = max(
+        xrp_to_drops(0.1),  # a fee that is obviously too high
+        await _calculate_fee_per_transaction_type(transaction, client),
+    )
 
     if transaction.fee and int(transaction.fee) > int(expected_fee):
         raise XRPLException(
-            "Fee value: "
-            + str(drops_to_xrp(transaction.fee))
-            + " XRP exceeds the "
-            + str(drops_to_xrp(expected_fee))
-            + " maximum XRP fee limit for "
-            + transaction.transaction_type
-            + " transaction"
+            f"Fee value: {str(drops_to_xrp(transaction.fee))} XRP is likely entered "
+            "incorrectly, since it is much larger than the typical XRP transaction "
+            "cost. If this is intentional, use `check_fee=False`."
         )
 
 
 async def _calculate_fee_per_transaction_type(
-    transaction: Transaction, client: Optional[Client] = None
+    transaction: Transaction,
+    client: Optional[Client] = None,
+    signers_count: Optional[int] = None,
 ) -> str:
     """
     Calculate the total fee in drops for a transaction based on:
@@ -297,6 +448,8 @@ async def _calculate_fee_per_transaction_type(
     Args:
         transaction: the Transaction to be submitted.
         client: the network client with which to submit the transaction.
+        signers_count: the expected number of signers for this transaction.
+            Only used for multisigned transactions.
 
     Returns:
         The expected Transaction fee in drops
@@ -327,14 +480,13 @@ async def _calculate_fee_per_transaction_type(
 
     # Multi-signed Transaction
     # 10 drops × (1 + Number of Signatures Provided)
-    if transaction.signers and len(transaction.signers) > 0:
-        base_fee = net_fee * (1 + len(transaction.signers)) + base_fee
-
+    if signers_count is not None and signers_count > 0:
+        base_fee += net_fee * (1 + signers_count)
     # Round Up base_fee and return it as a String
     return str(math.ceil(base_fee))
 
 
 async def _fetch_account_delete_fee(client: Client) -> int:
-    server_state = await client.request_impl(ServerState())
+    server_state = await client._request_impl(ServerState())
     fee = server_state.result["state"]["validated_ledger"]["reserve_inc"]
     return int(fee)
