@@ -6,22 +6,21 @@ See https://xrpl.org/currency-formats.html#specifying-currency-amounts
 """
 from __future__ import annotations
 
-import re
 from dataclasses import dataclass
-from typing import Dict
-
-from typing_extensions import Final
+from typing import Dict, Union
 
+import xrpl.models.amounts  # not a direct import, to get around circular imports
+from xrpl.constants import HEX_CURRENCY_REGEX, ISO_CURRENCY_REGEX
 from xrpl.models.base_model import BaseModel
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
-_CHAR: Final[str] = r"[A-Za-z\d\?!@#\$%\^&\*<>\(\){}\[\]\|]"
-_CURRENCY_CODE: Final[str] = f"{_CHAR}{{3}}"
-_HEX: Final[str] = f"{_CHAR}{{40}}"
-_VALIDATOR: Final[re.Pattern[str]] = re.compile(
-    f"(?:{_CURRENCY_CODE}|{_HEX})",
-)
+
+def _is_valid_currency(candidate: str) -> bool:
+    return bool(
+        ISO_CURRENCY_REGEX.fullmatch(candidate)
+        or HEX_CURRENCY_REGEX.fullmatch(candidate)
+    )
 
 
 @require_kwargs_on_init
@@ -52,6 +51,23 @@ class IssuedCurrency(BaseModel):
         errors = super()._get_errors()
         if self.currency.upper() == "XRP":
             errors["currency"] = "Currency must not be XRP for issued currency"
-        elif not _VALIDATOR.fullmatch(self.currency):
+        elif not _is_valid_currency(self.currency):
             errors["currency"] = f"Invalid currency {self.currency}"
         return errors
+
+    def to_amount(
+        self: IssuedCurrency, value: Union[str, int, float]
+    ) -> xrpl.models.amounts.IssuedCurrencyAmount:
+        """
+        Converts an IssuedCurrency to an IssuedCurrencyAmount.
+
+        Args:
+            value: The amount of issued currency in the IssuedCurrencyAmount.
+
+        Returns:
+            An IssuedCurrencyAmount that represents the issued currency and the
+                provided value.
+        """
+        return xrpl.models.amounts.IssuedCurrencyAmount(
+            currency=self.currency, issuer=self.issuer, value=str(value)
+        )
