@@ -19,9 +19,11 @@ from xrpl.models.requests.ledger import Ledger
 from xrpl.models.requests.ledger_closed import LedgerClosed
 from xrpl.models.requests.ledger_current import LedgerCurrent
 from xrpl.models.requests.ledger_data import LedgerData
-from xrpl.models.requests.ledger_entry import LedgerEntry
+from xrpl.models.requests.ledger_entry import LedgerEntry, LedgerEntryType
 from xrpl.models.requests.manifest import Manifest
 from xrpl.models.requests.nft_buy_offers import NFTBuyOffers
+from xrpl.models.requests.nft_history import NFTHistory
+from xrpl.models.requests.nft_info import NFTInfo
 from xrpl.models.requests.nft_sell_offers import NFTSellOffers
 from xrpl.models.requests.no_ripple_check import NoRippleCheck, NoRippleCheckRole
 from xrpl.models.requests.path_find import PathFind, PathFindSubcommand
@@ -37,7 +39,7 @@ from xrpl.models.requests.sign_for import SignFor
 from xrpl.models.requests.submit import Submit
 from xrpl.models.requests.submit_multisigned import SubmitMultisigned
 from xrpl.models.requests.submit_only import SubmitOnly
-from xrpl.models.requests.subscribe import StreamParameter, Subscribe
+from xrpl.models.requests.subscribe import StreamParameter, Subscribe, SubscribeBook
 from xrpl.models.requests.transaction_entry import TransactionEntry
 from xrpl.models.requests.tx import Tx
 from xrpl.models.requests.unsubscribe import Unsubscribe
@@ -64,9 +66,12 @@ __all__ = [
     "LedgerCurrent",
     "LedgerData",
     "LedgerEntry",
+    "LedgerEntryType",
     "Manifest",
     "NFTBuyOffers",
     "NFTSellOffers",
+    "NFTInfo",
+    "NFTHistory",
     "NoRippleCheck",
     "NoRippleCheckRole",
     "PathFind",
@@ -86,6 +91,7 @@ __all__ = [
     "SubmitOnly",
     "StreamParameter",
     "Subscribe",
+    "SubscribeBook",
     "TransactionEntry",
     "Tx",
     "Unsubscribe",
