@@ -8,16 +8,15 @@ interfaces.
 `See account_currencies <https://xrpl.org/account_currencies.html>`_
 """
 from dataclasses import dataclass, field
-from typing import Optional, Union
 
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class AccountCurrencies(Request):
+class AccountCurrencies(Request, LookupByLedgerRequest):
     """
     This request retrieves a list of currencies that an account can send or receive,
     based on its trust lines.
@@ -34,8 +33,5 @@ class AccountCurrencies(Request):
 
     :meta hide-value:
     """
-
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
     method: RequestMethod = field(default=RequestMethod.ACCOUNT_CURRENCIES, init=False)
     strict: bool = False
