@@ -6,16 +6,16 @@ particular version of the ledger.
 `See account_lines <https://xrpl.org/account_lines.html>`_
 """
 from dataclasses import dataclass, field
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class AccountLines(Request):
+class AccountLines(Request, LookupByLedgerRequest):
     """
     This request returns information about an account's trust lines, including balances
     in all non-XRP currencies and assets. All information retrieved is relative to a
@@ -24,10 +24,13 @@ class AccountLines(Request):
     `See account_lines <https://xrpl.org/account_lines.html>`_
     """
 
-    #: This field is required.
     account: str = REQUIRED  # type: ignore
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
+    """
+    This field is required.
+
+    :meta hide-value:
+    """
+
     method: RequestMethod = field(default=RequestMethod.ACCOUNT_LINES, init=False)
     peer: Optional[str] = None
     limit: Optional[int] = None
