@@ -5,16 +5,16 @@ specified account.
 `See account_tx <https://xrpl.org/account_tx.html>`_
 """
 from dataclasses import dataclass, field
-from typing import Any, Optional, Union
+from typing import Any, Optional
 
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class AccountTx(Request):
+class AccountTx(Request, LookupByLedgerRequest):
     """
     This request retrieves from the ledger a list of transactions that involved the
     specified account.
@@ -22,10 +22,13 @@ class AccountTx(Request):
     `See account_tx <https://xrpl.org/account_tx.html>`_
     """
 
-    #: This field is required.
     account: str = REQUIRED  # type: ignore
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
+    """
+    This field is required.
+
+    :meta hide-value:
+    """
+
     method: RequestMethod = field(default=RequestMethod.ACCOUNT_TX, init=False)
     ledger_index_min: Optional[int] = None
     ledger_index_max: Optional[int] = None
