@@ -8,14 +8,34 @@ different types of objects you can retrieve.
 from __future__ import annotations
 
 from dataclasses import dataclass, field
+from enum import Enum
 from typing import Dict, List, Optional, Union
 
 from xrpl.models.base_model import BaseModel
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
+class LedgerEntryType(str, Enum):
+    """Identifiers for on-ledger objects."""
+
+    ACCOUNT = "account"
+    AMENDMENTS = "amendments"
+    CHECK = "check"
+    DEPOSIT_PREAUTH = "deposit_preauth"
+    DIRECTORY = "directory"
+    ESCROW = "escrow"
+    FEE = "fee"
+    HASHES = "hashes"
+    OFFER = "offer"
+    PAYMENT_CHANNEL = "payment_channel"
+    SIGNER_LIST = "signer_list"
+    STATE = "state"
+    TICKET = "ticket"
+    NFT_OFFER = "nft_offer"
+
+
 @require_kwargs_on_init
 @dataclass(frozen=True)
 class DepositPreauth(BaseModel):
@@ -154,7 +174,7 @@ class Ticket(BaseModel):
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class LedgerEntry(Request):
+class LedgerEntry(Request, LookupByLedgerRequest):
     """
     The ledger_entry method returns a single ledger
     object from the XRP Ledger in its raw format.
@@ -175,8 +195,8 @@ class LedgerEntry(Request):
     ripple_state: Optional[RippleState] = None
     ticket: Optional[Union[str, Ticket]] = None
     binary: bool = False
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
+    nft_page: Optional[str] = None
+    """Must be the object ID of the NFToken page, as hexadecimal"""
 
     def _get_errors(self: LedgerEntry) -> Dict[str, str]:
         errors = super()._get_errors()
