@@ -7,9 +7,9 @@ recommended settings.
 """
 from dataclasses import dataclass, field
 from enum import Enum
-from typing import Optional, Union
+from typing import Optional
 
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
@@ -23,7 +23,7 @@ class NoRippleCheckRole(str, Enum):
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class NoRippleCheck(Request):
+class NoRippleCheck(Request, LookupByLedgerRequest):
     """
     This request provides a quick way to check the status of the Default Ripple field
     for an account and the No Ripple flag of its trust lines, compared with the
@@ -39,8 +39,6 @@ class NoRippleCheck(Request):
     :meta hide-value:
     """
 
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
     method: RequestMethod = field(default=RequestMethod.NO_RIPPLE_CHECK, init=False)
     role: NoRippleCheckRole = REQUIRED  # type: ignore
     """
