@@ -6,7 +6,7 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from enum import Enum
-from typing import Any, Dict, Optional, Type, Union, cast
+from typing import Any, Dict, Optional, Type, TypeVar, Union, cast
 
 import xrpl.models.requests  # bare import to get around circular dependency
 from xrpl.models.base_model import BaseModel
@@ -58,6 +58,8 @@ class RequestMethod(str, Enum):
     # NFT methods
     NFT_BUY_OFFERS = "nft_buy_offers"
     NFT_SELL_OFFERS = "nft_sell_offers"
+    NFT_INFO = "nft_info"  # clio only
+    NFT_HISTORY = "nft_history"  # clio only
 
     # subscription methods
     SUBSCRIBE = "subscribe"
@@ -73,15 +75,14 @@ class RequestMethod(str, Enum):
     PING = "ping"
     RANDOM = "random"
 
-    # sidechain methods
-    FEDERATOR_INFO = "federator_info"
-
     # generic unknown/unsupported request
     # (there is no XRPL analog, this model is specific to xrpl-py)
     GENERIC_REQUEST = "zzgeneric_request"
 
 
-@require_kwargs_on_init
+R = TypeVar("R", bound="Request")
+
+
 @dataclass(frozen=True)
 class Request(BaseModel):
     """
@@ -99,7 +100,7 @@ class Request(BaseModel):
     id: Optional[Union[str, int]] = None
 
     @classmethod
-    def from_dict(cls: Type[Request], value: Dict[str, Any]) -> Request:
+    def from_dict(cls: Type[R], value: Dict[str, Any]) -> R:
         """
         Construct a new Request from a dictionary of parameters.
 
@@ -116,7 +117,7 @@ class Request(BaseModel):
             if "method" not in value:
                 raise XRPLModelException("Request does not include method.")
             correct_type = cls.get_method(value["method"])
-            return correct_type.from_dict(value)
+            return correct_type.from_dict(value)  # type: ignore
 
         if "method" in value:
             method = value["method"]
@@ -135,7 +136,7 @@ class Request(BaseModel):
             value = {**value}
             del value["method"]
 
-        return cast(Request, super(Request, cls).from_dict(value))
+        return super(Request, cls).from_dict(value)
 
     @classmethod
     def get_method(cls: Type[Request], method: str) -> Type[Request]:
@@ -158,6 +159,10 @@ class Request(BaseModel):
             return xrpl.models.requests.NFTBuyOffers
         if method == RequestMethod.NFT_SELL_OFFERS:
             return xrpl.models.requests.NFTSellOffers
+        if method == RequestMethod.NFT_INFO:
+            return xrpl.models.requests.NFTInfo
+        if method == RequestMethod.NFT_HISTORY:
+            return xrpl.models.requests.NFTHistory
 
         parsed_name = "".join([word.capitalize() for word in method.split("_")])
         if parsed_name in xrpl.models.requests.__all__:
@@ -174,3 +179,18 @@ class Request(BaseModel):
         # we need to override this because method is using ``field``
         # which will not include the value in the object's __dict__
         return {**super().to_dict(), "method": self.method.value}
+
+
+@require_kwargs_on_init
+@dataclass(frozen=True)
+class LookupByLedgerRequest:
+    """Represents requests that need specifying an instance of the ledger"""
+
+    ledger_hash: Optional[str] = None
+    """
+    A 20-byte hex string for the ledger version to use.
+    """
+    ledger_index: Optional[Union[str, int]] = None
+    """
+    The ledger index of the ledger to use, or a shortcut string.
+    """
