@@ -12,18 +12,18 @@ combination of paths for making a payment, it is not guaranteed that
 the paths returned by this method are, in fact, the best paths.
 """
 from dataclasses import dataclass, field
-from typing import List, Optional, Union
+from typing import List, Optional
 
 from xrpl.models.amounts import Amount
 from xrpl.models.currencies import Currency
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class RipplePathFind(Request):
+class RipplePathFind(Request, LookupByLedgerRequest):
     """
     The ripple_path_find method is a simplified version of the
     path_find method that provides a single response with a payment
@@ -62,5 +62,3 @@ class RipplePathFind(Request):
     method: RequestMethod = field(default=RequestMethod.RIPPLE_PATH_FIND, init=False)
     send_max: Optional[Amount] = None
     source_currencies: Optional[List[Currency]] = None
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
