@@ -9,16 +9,15 @@ specified transaction. We recommend using that method instead.)
 from __future__ import annotations
 
 from dataclasses import dataclass, field
-from typing import Optional, Union
 
-from xrpl.models.requests.request import Request, RequestMethod
+from xrpl.models.requests.request import LookupByLedgerRequest, Request, RequestMethod
 from xrpl.models.required import REQUIRED
 from xrpl.models.utils import require_kwargs_on_init
 
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class TransactionEntry(Request):
+class TransactionEntry(Request, LookupByLedgerRequest):
     """
     The transaction_entry method retrieves information on a single transaction from a
     specific ledger version. (The tx method, by contrast, searches all ledgers for the
@@ -28,8 +27,6 @@ class TransactionEntry(Request):
     """
 
     method: RequestMethod = field(default=RequestMethod.TRANSACTION_ENTRY, init=False)
-    ledger_hash: Optional[str] = None
-    ledger_index: Optional[Union[str, int]] = None
     tx_hash: str = REQUIRED  # type: ignore
     """
     This field is required.
