@@ -16,6 +16,7 @@ from xrpl.models.transactions.deposit_preauth import DepositPreauth
 from xrpl.models.transactions.escrow_cancel import EscrowCancel
 from xrpl.models.transactions.escrow_create import EscrowCreate
 from xrpl.models.transactions.escrow_finish import EscrowFinish
+from xrpl.models.transactions.metadata import TransactionMetadata
 from xrpl.models.transactions.nftoken_accept_offer import NFTokenAcceptOffer
 from xrpl.models.transactions.nftoken_burn import NFTokenBurn
 from xrpl.models.transactions.nftoken_cancel_offer import NFTokenCancelOffer
@@ -93,6 +94,7 @@ __all__ = [
     "SignerListSet",
     "TicketCreate",
     "Transaction",
+    "TransactionMetadata",
     "TrustSet",
     "TrustSetFlag",
     "TrustSetFlagInterface",
