@@ -4,7 +4,8 @@ from dataclasses import dataclass, field
 from typing import Optional
 
 from xrpl.models.required import REQUIRED
-from xrpl.models.transactions.transaction import Transaction, TransactionType
+from xrpl.models.transactions.transaction import Transaction
+from xrpl.models.transactions.types import TransactionType
 from xrpl.models.utils import require_kwargs_on_init
 
 
@@ -22,14 +23,20 @@ class AccountDelete(Transaction):
     delete an account.
     """
 
-    #: The address of the account to send any remaining XRP to.
-    #: This field is required.
     destination: str = REQUIRED  # type: ignore
+    """
+    The address of the account to which to send any remaining XRP.
+    This field is required.
+
+    :meta hide-value:
+    """
 
-    #: The `destination tag
-    #: <https://xrpl.org/source-and-destination-tags.html>`_ at the
-    #: ``destination`` account where funds should be sent.
     destination_tag: Optional[int] = None
+    """
+    The `destination tag
+    <https://xrpl.org/source-and-destination-tags.html>`_ at the
+    ``destination`` account where funds should be sent.
+    """
 
     transaction_type: TransactionType = field(
         default=TransactionType.ACCOUNT_DELETE,
