@@ -7,6 +7,7 @@ from typing import Dict, Optional
 
 from typing_extensions import Final
 
+from xrpl.models.flags import FlagInterface
 from xrpl.models.transactions.transaction import Transaction
 from xrpl.models.transactions.types import TransactionType
 from xrpl.models.utils import require_kwargs_on_init
@@ -85,9 +86,49 @@ class AccountSetFlag(int, Enum):
     ASF_REQUIRE_DEST = 1
     """Require a destination tag to send transactions to this account."""
 
-    ASF_AUTHORIZED_MINTER = 10
+    ASF_AUTHORIZED_NFTOKEN_MINTER = 10
     """Allow another account to mint and burn tokens on behalf of this account."""
 
+    ASF_DISABLE_INCOMING_NFTOKEN_OFFER = 12
+    """Disallow other accounts from creating NFTokenOffers directed at this account."""
+
+    ASF_DISABLE_INCOMING_CHECK = 13
+    """Disallow other accounts from creating Checks directed at this account."""
+
+    ASF_DISABLE_INCOMING_PAYCHAN = 14
+    """Disallow other accounts from creating PayChannels directed at this account."""
+
+    ASF_DISABLE_INCOMING_TRUSTLINE = 15
+    """Disallow other accounts from creating Trustlines directed at this account."""
+
+
+class AccountSetFlagInterface(FlagInterface):
+    """
+    There are several options which can be either enabled or disabled for an account.
+    Account options are represented by different types of flags depending on the
+    situation. The AccountSet transaction type has several "AccountSet Flags" (prefixed
+    `asf`) that can enable an option when passed as the SetFlag parameter, or disable
+    an option when passed as the ClearFlag parameter. This TypedDict represents those
+    options.
+
+    `See AccountSet Flags <https://xrpl.org/accountset.html#accountset-flags>`_
+    """
+
+    ASF_ACCOUNT_TXN_ID: bool
+    ASF_DEFAULT_RIPPLE: bool
+    ASF_DEPOSIT_AUTH: bool
+    ASF_DISABLE_MASTER: bool
+    ASF_DISALLOW_XRP: bool
+    ASF_GLOBAL_FREEZE: bool
+    ASF_NO_FREEZE: bool
+    ASF_REQUIRE_AUTH: bool
+    ASF_REQUIRE_DEST: bool
+    ASF_AUTHORIZED_NFTOKEN_MINTER: bool
+    ASF_DISABLE_INCOMING_NFTOKEN_OFFER: bool
+    ASF_DISABLE_INCOMING_CHECK: bool
+    ASF_DISABLE_INCOMING_PAYCHAN: bool
+    ASF_DISABLE_INCOMING_TRUSTLINE: bool
+
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
@@ -138,11 +179,11 @@ class AccountSet(Transaction):
     <https://xrpl.org/ticksize.html>`_ for details.
     """
 
-    minter: Optional[str] = None
+    nftoken_minter: Optional[str] = None
     """
     Sets an alternate account that is allowed to mint NFTokens on this
     account's behalf using NFTokenMint's `Issuer` field. If set, you must
-    also set the AccountSetFlag.ASF_AUTHORIZED_MINTER flag.
+    also set the AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER flag.
     """
 
     transaction_type: TransactionType = field(
@@ -159,7 +200,7 @@ class AccountSet(Transaction):
                 "transfer_rate": self._get_transfer_rate_error(),
                 "domain": self._get_domain_error(),
                 "clear_flag": self._get_clear_flag_error(),
-                "minter": self._get_minter_error(),
+                "nftoken_minter": self._get_nftoken_minter_error(),
             }.items()
             if value is not None
         }
@@ -197,26 +238,27 @@ class AccountSet(Transaction):
             return "Must not be equal to the set_flag"
         return None
 
-    def _get_minter_error(self: AccountSet) -> Optional[str]:
+    def _get_nftoken_minter_error(self: AccountSet) -> Optional[str]:
         if (
-            self.set_flag != AccountSetFlag.ASF_AUTHORIZED_MINTER
-            and self.minter is not None
+            self.set_flag != AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER
+            and self.nftoken_minter is not None
         ):
             return (
                 "Will not set the minter unless "
-                "AccountSetFlag.ASF_AUTHORIZED_MINTER is set"
+                "AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER is set"
             )
         if (
-            self.set_flag == AccountSetFlag.ASF_AUTHORIZED_MINTER
-            and self.minter is None
+            self.set_flag == AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER
+            and self.nftoken_minter is None
         ):
-            return "Must be present if AccountSetFlag.ASF_AUTHORIZED_MINTER is set"
+            return "\
+                Must be present if AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER is set"
         if (
-            self.clear_flag == AccountSetFlag.ASF_AUTHORIZED_MINTER
-            and self.minter is not None
+            self.clear_flag == AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER
+            and self.nftoken_minter is not None
         ):
             return (
-                "Must not be present if AccountSetFlag.ASF_AUTHORIZED_MINTER "
+                "Must not be present if AccountSetFlag.ASF_AUTHORIZED_NFTOKEN_MINTER "
                 "is unset using clear_flag"
             )
         return None
