@@ -3,15 +3,16 @@ from __future__ import annotations
 
 from dataclasses import dataclass
 from hashlib import sha512
-from typing import Any, Dict, List, Optional, Type, Union, cast
+from typing import Any, Dict, List, Optional, Type, TypeVar, Union
 
 from typing_extensions import Final
 
-from xrpl.core.binarycodec import encode
+from xrpl.core.binarycodec import decode, encode
 from xrpl.models.amounts import IssuedCurrencyAmount
 from xrpl.models.base_model import BaseModel
 from xrpl.models.exceptions import XRPLModelException
 from xrpl.models.flags import check_false_flag_definition, interface_to_flag_list
+from xrpl.models.nested_model import NestedModel
 from xrpl.models.requests import PathStep
 from xrpl.models.required import REQUIRED
 from xrpl.models.transactions.types import PseudoTransactionType, TransactionType
@@ -79,7 +80,7 @@ def _value_to_tx_json(value: XRPL_VALUE_TYPE) -> XRPL_VALUE_TYPE:
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class Memo(BaseModel):
+class Memo(NestedModel):
     """
     An arbitrary piece of data attached to a transaction. A transaction can
     have multiple Memo objects as an array in the Memos field.
@@ -121,37 +122,10 @@ class Memo(BaseModel):
             errors["Memo"] = "Memo must contain at least one field"
         return errors
 
-    @classmethod
-    def from_dict(cls: Type[Memo], value: Dict[str, Any]) -> Memo:
-        """
-        Construct a new Memo from a dictionary of parameters.
-
-        Args:
-            value: The value to construct the Memo from.
-
-        Returns:
-            A new Memo object, constructed using the given parameters.
-
-        Raises:
-            XRPLModelException: If the dictionary provided is invalid.
-        """
-        if "memo" not in value:
-            return cast(Memo, super(Memo, cls).from_dict(value))
-        return cast(Memo, super(Memo, cls).from_dict(value["memo"]))
-
-    def to_dict(self: Memo) -> Dict[str, Any]:
-        """
-        Returns the dictionary representation of a Memo.
-
-        Returns:
-            The dictionary representation of a Memo.
-        """
-        return {"memo": super().to_dict()}
-
 
 @require_kwargs_on_init
 @dataclass(frozen=True)
-class Signer(BaseModel):
+class Signer(NestedModel):
     """
     One Signer in a multi-signature. A multi-signed transaction can have an
     array of up to 8 Signers, each contributing a signature, in the Signers
@@ -183,56 +157,8 @@ class Signer(BaseModel):
     :meta hide-value:
     """
 
-    @classmethod
-    def is_dict_of_model(cls: Type[Signer], dictionary: Any) -> bool:
-        """
-        Returns True if the input dictionary was derived by the `to_dict`
-        method of an instance of this class. In other words, True if this is
-        a dictionary representation of an instance of this class.
 
-        NOTE: does not account for model inheritance, IE will only return True
-        if dictionary represents an instance of this class, but not if
-        dictionary represents an instance of a subclass of this class.
-
-        Args:
-            dictionary: The dictionary to check.
-
-        Returns:
-            True if dictionary is a dict representation of an instance of this
-            class.
-        """
-        return (
-            isinstance(dictionary, dict)
-            and "signer" in dictionary
-            and super().is_dict_of_model(dictionary["signer"])
-        )
-
-    @classmethod
-    def from_dict(cls: Type[Signer], value: Dict[str, Any]) -> Signer:
-        """
-        Construct a new Signer from a dictionary of parameters.
-
-        Args:
-            value: The value to construct the Signer from.
-
-        Returns:
-            A new Signer object, constructed using the given parameters.
-
-        Raises:
-            XRPLModelException: If the dictionary provided is invalid.
-        """
-        if "signer" not in value:
-            return cast(Signer, super(Signer, cls).from_dict(value))
-        return cast(Signer, super(Signer, cls).from_dict(value["signer"]))
-
-    def to_dict(self: Signer) -> Dict[str, Any]:
-        """
-        Returns the dictionary representation of a Signer.
-
-        Returns:
-            The dictionary representation of a Signer.
-        """
-        return {"signer": super().to_dict()}
+T = TypeVar("T", bound="Transaction")  # any type inherited from Transaction
 
 
 @require_kwargs_on_init
@@ -317,12 +243,33 @@ class Transaction(BaseModel):
     added during signing.
     """
 
+    ticket_sequence: Optional[int] = None
+    """
+    The sequence number of the ticket to use in place of a Sequence number. If
+    this is provided, sequence must be 0. Cannot be used with account_txn_id.
+    """
+
     txn_signature: Optional[str] = None
     """
     The cryptographic signature from the sender that authorizes this
     transaction. Automatically added during signing.
     """
 
+    network_id: Optional[int] = None
+    """The network id of the transaction."""
+
+    def _get_errors(self: Transaction) -> Dict[str, str]:
+        errors = super()._get_errors()
+        if self.ticket_sequence is not None and (
+            (self.sequence is not None and self.sequence != 0)
+            or self.account_txn_id is not None
+        ):
+            errors[
+                "Transaction"
+            ] = """If ticket_sequence is provided,
+            account_txn_id must be None and sequence must be None or 0"""
+        return errors
+
     def to_dict(self: Transaction) -> Dict[str, Any]:
         """
         Returns the dictionary representation of a Transaction.
@@ -372,8 +319,17 @@ class Transaction(BaseModel):
         """
         return transaction_json_to_binary_codec_form(self.to_dict())
 
+    def blob(self: Transaction) -> str:
+        """
+        Creates the canonical binary format of the Transaction object.
+
+        Returns:
+            The binary-encoded object, as a hexadecimal string.
+        """
+        return encode(self.to_xrpl())
+
     @classmethod
-    def from_dict(cls: Type[Transaction], value: Dict[str, Any]) -> Transaction:
+    def from_dict(cls: Type[T], value: Dict[str, Any]) -> T:
         """
         Construct a new Transaction from a dictionary of parameters.
 
@@ -393,7 +349,7 @@ class Transaction(BaseModel):
                     "Transaction does not include transaction_type."
                 )
             correct_type = cls.get_transaction_type(value["transaction_type"])
-            return correct_type.from_dict(value)
+            return correct_type.from_dict(value)  # type: ignore
         else:
             if "transaction_type" in value:
                 if value["transaction_type"] != cls.__name__:
@@ -404,7 +360,7 @@ class Transaction(BaseModel):
                     )
                 value = {**value}
                 del value["transaction_type"]
-            return cast(Transaction, super(Transaction, cls).from_dict(value))
+            return super(Transaction, cls).from_dict(value)
 
     def has_flag(self: Transaction, flag: int) -> bool:
         """
@@ -427,6 +383,24 @@ class Transaction(BaseModel):
         else:  # is List[int]
             return flag in self.flags
 
+    def is_signed(self: Transaction) -> bool:
+        """
+        Checks if a transaction has been signed.
+
+        Returns:
+            Whether the transaction has been signed
+        """
+        if self.signers:
+            for signer in self.signers:
+                if (
+                    signer.signing_pub_key is None or len(signer.signing_pub_key) <= 0
+                ) or (signer.txn_signature is None or len(signer.txn_signature) <= 0):
+                    return False
+            return True
+        return (
+            self.signing_pub_key is not None and len(self.signing_pub_key) > 0
+        ) and (self.txn_signature is not None and len(self.txn_signature) > 0)
+
     def get_hash(self: Transaction) -> str:
         """
         Hashes the Transaction object as the ledger does. Only valid for signed
@@ -438,7 +412,7 @@ class Transaction(BaseModel):
         Raises:
             XRPLModelException: if the Transaction is unsigned.
         """
-        if self.txn_signature is None:
+        if self.txn_signature is None and self.signers is None:
             raise XRPLModelException(
                 "Cannot get the hash from an unsigned Transaction."
             )
@@ -480,3 +454,16 @@ class Transaction(BaseModel):
             return pseudo_transaction_types[transaction_type]
 
         raise XRPLModelException(f"{transaction_type} is not a valid Transaction type")
+
+    @staticmethod
+    def from_blob(tx_blob: str) -> Transaction:
+        """
+        Decodes a transaction blob.
+
+        Args:
+            tx_blob: the tx blob to decode.
+
+        Returns:
+            The formatted transaction.
+        """
+        return Transaction.from_xrpl(decode(tx_blob))
