@@ -6,21 +6,35 @@ from xrpl.asyncio.transaction import (
 from xrpl.transaction.ledger import get_transaction_from_hash
 from xrpl.transaction.main import (
     autofill,
+    autofill_and_sign,
     safe_sign_and_autofill_transaction,
     safe_sign_and_submit_transaction,
     safe_sign_transaction,
+    sign,
+    sign_and_submit,
+    submit,
     submit_transaction,
 )
-from xrpl.transaction.reliable_submission import send_reliable_submission
+from xrpl.transaction.multisign import multisign
+from xrpl.transaction.reliable_submission import (
+    send_reliable_submission,
+    submit_and_wait,
+)
 
 __all__ = [
     "autofill",
+    "autofill_and_sign",
     "get_transaction_from_hash",
     "safe_sign_transaction",
     "safe_sign_and_autofill_transaction",
     "safe_sign_and_submit_transaction",
+    "sign",
+    "sign_and_submit",
+    "submit",
+    "submit_and_wait",
     "submit_transaction",
     "transaction_json_to_binary_codec_form",
     "send_reliable_submission",
+    "multisign",
     "XRPLReliableSubmissionException",
 ]
