@@ -1,6 +1,5 @@
 """Convenience utilities for the XRP Ledger"""
 
-from xrpl.utils.sidechain import create_cross_chain_payment
 from xrpl.utils.str_conversions import hex_to_str, str_to_hex
 from xrpl.utils.time_conversions import (
     XRPLTimeRangeException,
@@ -9,6 +8,11 @@ from xrpl.utils.time_conversions import (
     ripple_time_to_datetime,
     ripple_time_to_posix,
 )
+from xrpl.utils.txn_parser import (
+    get_balance_changes,
+    get_final_balances,
+    get_order_book_changes,
+)
 from xrpl.utils.xrp_conversions import XRPRangeException, drops_to_xrp, xrp_to_drops
 
 __all__ = [
@@ -22,5 +26,7 @@ __all__ = [
     "posix_to_ripple_time",
     "XRPRangeException",
     "XRPLTimeRangeException",
-    "create_cross_chain_payment",
+    "get_balance_changes",
+    "get_final_balances",
+    "get_order_book_changes",
 ]
